.. include:: includes.rst

Length Rules
------------

These rules cover the length of lines in the VHDL file.

length_001
##########

|phase_7| |warning| |unfixable| |length|

This rule checks the length of the line.

|configuring_length_rules_link|

length_002
##########

|phase_7| |warning| |unfixable| |length|

This rule checks the length of a file.

|configuring_length_rules_link|

length_003
##########

|phase_7| |warning| |unfixable| |length|

This rule checks the length of a process statement.

|configuring_length_rules_link|
